// @ts-check
import { defineConfig } from 'astro/config';
import mdx from '@astrojs/mdx';
import vue from "@astrojs/vue";
import compressor from "astro-compressor";
import purgecss from 'astro-purgecss';

export default defineConfig({
  site: 'https://sudovanilla.org',
  redirects: {
    '/docs/': '/docs/zorn/introduction/',
    '/docs/minpluto': '/docs/zorn/introduction/',
    '/on-premise-policy': '/umbrella-policy'
  },
  integrations: [
    compressor(),
    mdx(),
    vue(),
    purgecss({
      fontFace: true,
      keyframes: true
    })
  ],
  output: 'static',
  build: {
    inlineStylesheets: 'never'
  },
  server: {
    port: 5522,
    host: true
  },
  // None of this vite crap works, Caddy is used in Docker in production that points to /dists/ instead
  vite: {
    server: {
      host: "sudovanilla.org"
    },
    preview: {
      allowedHosts: true
    }
  },
  devToolbar: {
    enabled: false
  }
});